pub struct Usbhsh { /* private fields */ }Expand description
LPC-Next0 USB1 High-speed Host Controller
Implementations
Sourceimpl Usbhsh
impl Usbhsh
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn caplength_chipid(self) -> Reg<CaplengthChipid, R>
pub const fn caplength_chipid(self) -> Reg<CaplengthChipid, R>
This register contains the offset value towards the start of the operational register space and the version number of the IP block
Sourcepub const fn fladj_frindex(self) -> Reg<FladjFrindex, RW>
pub const fn fladj_frindex(self) -> Reg<FladjFrindex, RW>
Frame Length Adjustment
Sourcepub const fn datapayload(self) -> Reg<Datapayload, RW>
pub const fn datapayload(self) -> Reg<Datapayload, RW>
Memory base address that indicates the start of the data payload buffers